Instalacija ONLYOFFICE Workspace Community korišćenjem dodatnih parametara skripta
Uvod
ONLYOFFICE Workspace Community je besplatna verzija kolaborativnog sistema razvijena za upravljanje dokumentima, projektima, odnosima sa klijentima i email korespondencijom, sve na jednom mestu.
ONLYOFFICE Workspace Community dolazi kao automatski instalacioni skript za Linux operativne sisteme sa instaliranim Docker-om. Skript postavlja Docker kontejnere sa svim komponentama potrebnim za ispravan rad ONLYOFFICE Workspace Community i lako ga je pokrenuti, upravljati i ažurirati.
Nakon što preuzmete instalacioni skript ONLYOFFICE Workspace Community, možda ćete morati da ga pokrenete sa dodatnim parametrima, na primer, da biste instalirali svaku komponentu na zasebnom serveru. Koristite sledeću komandu da biste prikazali listu svih dostupnih parametara skripta:
bash workspace-install.sh -h
U nastavku možete pronaći kratak opis i nekoliko primera korišćenja ovih parametara.
Naziv slike
| Parametar | Opis |
|---|---|
-ci, --communityimage | Naziv slike ONLYOFFICE Community Server |
-di, --documentimage | Naziv slike ONLYOFFICE Docs |
-mi, --mailimage | Naziv slike ONLYOFFICE Mail |
-cpi, --controlpanelimage | Naziv slike ONLYOFFICE Control Panel |
Ovi parametri određuju naziv slike iz koje treba pokrenuti kontejner. Navedena slika mora biti dostupna u zvaničnom javnom repozitorijumu na Docker Hub-u.
Primer
bash workspace-install.sh -ims false -di onlyoffice/documentserver -ics true -icp true
Ovo će pokrenuti kontejner iz navedene slike ONLYOFFICE Docs sačuvane u repozitorijumu, kao i kontejnere ONLYOFFICE Community Server i ONLYOFFICE Control Panel.
Verzija komponente
| Parametar | Opis |
|---|---|
-cv, --communityversion | Verzija ONLYOFFICE Community Server |
-dv, --documentversion | Verzija ONLYOFFICE Docs |
-mv, --mailversion | Verzija ONLYOFFICE Mail |
-cpv, --controlpanelversion | Verzija ONLYOFFICE Control Panel |
Ovi parametri omogućavaju instalaciju određene verzije komponente ako ne želite da koristite najnoviju verziju dostupnu u repozitorijumu. Podrazumevano se za pokretanje kontejnera svake komponente koristi slika označena sa latest.
Primer
Otvorite repozitorijum Docker Hub u pregledaču, izaberite komponentu i idite na karticu Tags da biste videli sve dostupne oznake. Navedite verziju koju želite da instalirate za potrebne komponente:
bash workspace-install.sh -ics true -cv 8.9.0.150 -ids false -icp true -cpv 1.6.0.52 -ims true -md "yourdomain.com"
Ovo će instalirati ONLYOFFICE Community Server verziju 8.9.0.150, ONLYOFFICE Control Panel verziju 1.6.0.52 i najnoviju verziju ONLYOFFICE Mail jer njegova verzija nije eksplicitno navedena.
IP adresa servera
| Parametar | Opis |
|---|---|
-dip, --documentserverip | IP adresa ONLYOFFICE Docs |
-mip, --mailserverip | IP adresa ONLYOFFICE Mail |
-mdbip, --mailserverdbip | IP adresa baze podataka ONLYOFFICE Mail |
Ovi parametri se mogu koristiti za povezivanje komponenti ako ih instalirate na zasebnim mašinama.
Primer
bash workspace-install.sh -ics true -icp true -ids false -ims false -dip 192.168.3.202 -es false
Ovo će instalirati ONLYOFFICE Community Server sa ONLYOFFICE Control Panel i povezati ga sa ONLYOFFICE Docs instaliranim na drugoj mašini koja ima IP adresu 192.168.3.202.
Naziv domena ONLYOFFICE Mail
| Parametar | Opis |
|---|---|
-md, --maildomain | Naziv domena ONLYOFFICE Mail |
Ovaj parametar omogućava da navedete prilagođeni naziv domena koji će se koristiti za ONLYOFFICE Mail.
Primer
bash workspace-install.sh -md "yourdomain.com"
Ovo će instalirati sve komponente ONLYOFFICE Workspace Community, uključujući ONLYOFFICE Mail, sa navedenim nazivom domena yourdomain.com.
Vaša domena koja će se koristiti za održavanje korespondencije mora biti validna i konfigurisana za ovu mašinu (tj. treba da ima odgovarajući A zapis u DNS podešavanjima koji pokazuje na IP adresu mašine gde je instaliran ONLYOFFICE Mail).
U gornjoj komandi, parametar "yourdomain.com" treba shvatiti kao servisnu domenu za ONLYOFFICE Mail. Obično se navodi u MX zapisu domene koja će se koristiti za održavanje korespondencije. Uglavnom, "yourdomain.com" izgleda kao mx1.onlyoffice.com
Ažuriranje komponenti
| Parametar | Opis | Vrednosti | Podrazumevano |
|---|---|---|---|
-u, --update | koristi se za ažuriranje postojećih komponenti | true|false | false |
Ovaj parametar instalira najnovije verzije zastarelih komponenti ako su odgovarajuće komponente instalirane na vašoj mašini zastarele.
Primer
bash workspace-install.sh -u true
Ovo će zaustaviti kontejnere koje treba ažurirati, ukloniti ih i pokrenuti najnovije verzije odgovarajućih komponenti ONLYOFFICE Workspace. Kontejneri čija trenutna verzija odgovara najnovijoj dostupnoj neće biti zahvaćeni. Komponente preskočene tokom prethodne instalacije takođe će biti preskočene. Podaci portala biće automatski sačuvani.
Akreditivi
| Parametar | Opis |
|---|---|
-un, --username | dockerhub korisničko ime |
-p, --password | dockerhub lozinka |
Ovi parametri se koriste kada su dati akreditivi za pristup test repozitorijumu, što vam omogućava da pokrećete kontejnere iz slika sačuvanih u njemu.
Primer
bash workspace-install.sh -md "yourdomain.com" -un username -p password
Instalacija komponenti
| Parametar | Opis | Vrednosti | Podrazumevano |
|---|---|---|---|
-ics, --installcommunityserver | instaliraj ONLYOFFICE Community Server | true|false|pull | true |
-ids, --installdocumentserver | instaliraj ONLYOFFICE Docs | true|false|pull | true |
-ims, --installmailserver | instaliraj ONLYOFFICE Mail | true|false|pull | true |
-icp, --installcontrolpanel | instaliraj ONLYOFFICE Control Panel | true|false|pull | true |
Ovi parametri omogućavaju da odredite da li će se određena komponenta instalirati. Mogu se koristiti za instalaciju svake komponente na zasebnom serveru.
- Koristite vrednost
trueda biste instalirali komponentu. - Koristite vrednost
falseda biste preskočili instalaciju komponente. - Koristite vrednost
pullda biste preuzeli komponentu bez instalacije.
Primer
bash workspace-install.sh -ims false
Ovo će instalirati sve komponente ONLYOFFICE Workspace bez ONLYOFFICE Mail.
bash workspace-install.sh -ics false -ids true -icp false -ims false -es true
Ovo će preskočiti instalaciju ONLYOFFICE Mail, ONLYOFFICE Community Server i ONLYOFFICE Control Panel i instalirati samo ONLYOFFICE Docs.
Tip instalacije
| Parametar | Opis | Vrednosti | Podrazumevano |
|---|---|---|---|
-it, --installation_type | tip instalacije | WORKSPACE|WORKSPACE_ENTERPRISE | WORKSPACE_ENTERPRISE |
Ovaj parametar instalira navedeno rešenje: ONLYOFFICE Workspace ili ONLYOFFICE Workspace Enterprise Edition.
Primer
bash workspace-install.sh -it GROUPS
Ovo će instalirati rešenje ONLYOFFICE Workspace koje uključuje komponente ONLYOFFICE Community Server i ONLYOFFICE Control Panel.
Korišćenje komponente kao spoljnog servera
| Parametar | Opis | Vrednosti | Podrazumevano |
|---|---|---|---|
-es, --useasexternalserver | koristi kao spoljni server | true|false | false |
Ovaj parametar se koristi pri instalaciji komponenti na zasebnim serverima.
- Koristite vrednost
truekada instalirate ONLYOFFICE Docs i ONLYOFFICE Mail na zasebnim mašinama. - Koristite vrednost
falsekada instalirate ONLYOFFICE Community Server zajedno sa ONLYOFFICE Control Panel na zasebnoj mašini.
Primer
bash workspace-install.sh -ics false -ids false -icp false -ims true -md "yourdomain.com" -es true
Ovo će preskočiti instalaciju ONLYOFFICE Docs, ONLYOFFICE Community Server i ONLYOFFICE Control Panel i instalirati samo ONLYOFFICE Mail.
bash workspace-install.sh -ics true -icp true -ids false -ims false -dip 192.168.3.202 -es false
Ovo će instalirati ONLYOFFICE Community Server sa ONLYOFFICE Control Panel i povezati ga sa ONLYOFFICE Docs instaliranim na drugoj mašini.
Kreiranje swap fajla
| Parametar | Opis | Vrednosti | Podrazumevano |
|---|---|---|---|
-ms, --makeswap | napravi swap fajl | true|false | false |
Ovaj parametar kreira swap fajl od 6 GB. Podrazumevano je navedena vrednost true, pa ne morate da navodite ovaj parametar pri pokretanju skripta. Swap fajl će biti kreiran automatski.
Primer
bash workspace-install.sh -ms false
Ako swap fajl već postoji, koristite ovu komandu da biste sprečili kreiranje novog swap fajla tokom instalacije.
Ako ponovo pokrenete skript bez parametra -ms, on proverava da li onlyoffice_swapfile postoji. Ako swap fajl već postoji, skript ga neće ponovo kreirati.
MySQL server
| Parametar | Opis | Podrazumevano |
|---|---|---|
-mysqlh, --mysqlhost | Host MySQL servera | localhost |
-mysqlprt, --mysqlport | Port MySQL servera | 3306 |
-mysqlru, --mysqlrootuser | Root korisnik MySQL servera | root |
-mysqlrp, --mysqlrootpassword | Root lozinka MySQL servera | my-secret-pw |
Ako ove parametre ne navedete eksplicitno, koriste se podrazumevane vrednosti.
Primer
bash workspace-install.sh -mysqlru root -mysqlrp new-secret-pw
Ova komanda postavlja prilagođenu lozinku za MySQL root nalog tokom instalacije ONLYOFFICE Workspace.
Baza podataka ONLYOFFICE Community Server
| Parametar | Opis | Podrazumevano |
|---|---|---|
-mysqld, --mysqldatabase | Naziv baze podataka ONLYOFFICE Community Server | onlyoffice |
-mysqlu, --mysqluser | Korisnik baze podataka ONLYOFFICE Community Server | onlyoffice_user |
-mysqlp, --mysqlpassword | Lozinka baze podataka ONLYOFFICE Community Server | onlyoffice_pass |
Ovi parametri omogućavaju kreiranje baze podataka ONLYOFFICE Community Server sa prilagođenim nazivom, zajedno sa korisničkim imenom i lozinkom za nalog sa dozvolama superkorisnika. Ako ove parametre ne navedete eksplicitno, koriste se podrazumevane vrednosti.
Primer
bash workspace-install.sh -mysqld communitydatabase -mysqlu username -mysqlp password
Baza podataka ONLYOFFICE Mail
| Parametar | Opis | Podrazumevano |
|---|---|---|
-mysqlmd, --mysqlmaildatabase | Naziv baze podataka ONLYOFFICE Mail | onlyoffice_mailserver |
-mysqlmu, --mysqlmailuser | Korisnik baze podataka ONLYOFFICE Mail | mail_admin |
-mysqlmp, --mysqlmailpassword | Lozinka baze podataka ONLYOFFICE Mail | Isadmin123 |
Ovi parametri omogućavaju kreiranje baze podataka ONLYOFFICE Mail uz navođenje prilagođenog naziva baze podataka, kao i korisničkog imena i lozinke za nalog sa dozvolama superkorisnika nad kreiranom bazom. Ako ove parametre ne navedete eksplicitno, koriste se podrazumevane vrednosti.
Primer
bash workspace-install.sh -md "mx.yourdomain.com" -mysqlmd maildatabase -mysqlmu username -mysqlmp password
Port ONLYOFFICE Community Server
| Parametar | Opis | Podrazumevano |
|---|---|---|
-cp, --communityport | Port ONLYOFFICE Community Server | 80 |
Ovaj parametar menja port na kojem radi ONLYOFFICE Community Server. Podrazumevani port je 80.
Primer
bash workspace-install.sh -cp 8080
Podešavanje za core.machinekey
| Parametar | Opis |
|---|---|
-mk, --machinekey | Podešavanje za ključ core.machinekey |
Ovaj parametar omogućava da navedete prilagođeni machinekey prilikom instalacije ONLYOFFICE Workspace Community.
Ovaj parametar se upisuje u konfiguracioni fajl /app/onlyoffice/CommunityServer/data/.private/machinekey.
Primer
bash workspace-install.sh -mk yourmachinekey
Podešavanje za JWT tajnu
| Parametar | Opis |
|---|---|
-jwt, --jwtsecret | Podešavanje za JWT tajni ključ |
Ovaj parametar omogućava da navedete prilagođeni JWT tajni ključ prilikom instalacije ONLYOFFICE Workspace Community. Tajni ključ se koristi za potpisivanje JSON veb tokena i proveru tokena prilikom zahteva ka ONLYOFFICE Docs.
Ovaj parametar se upisuje u sledeće konfiguracione fajlove (putanje su navedene unutar kontejnera):
- Za Community Server -
/var/www/onlyoffice/WebStudio/web.appsettings.config - Za Document Server -
/etc/onlyoffice/documentserver/local.json
Primer
bash workspace-install.sh -jwt yoursecret